@@ -11,7 +11,8 @@ def check_min_confidence(code, min_confidence, expected):
     v.scan(code)
     detected = {
         item.name: item.confidence
-        for item in v.get_unused_code(min_confidence=min_confidence)}
+        for item in v.get_unused_code(min_confidence=min_confidence)
+    }
     assert detected == expected
 
 
@@ -19,7 +20,7 @@ def test_confidence_import():
     code = """\
 import foo
 """
-    check_min_confidence(code, 50, {'foo': 90})
+    check_min_confidence(code, 50, {"foo": 90})
     check_min_confidence(code, 100, {})
 
 
@@ -31,8 +32,8 @@ def foo():
 
 foo()
 """
-    check_min_confidence(code, 50, {'return': 100})
-    check_min_confidence(code, 100, {'return': 100})
+    check_min_confidence(code, 50, {"return": 100})
+    check_min_confidence(code, 100, {"return": 100})
 
 
 def test_function_arg():
@@ -44,14 +45,14 @@ foo(5)
 """
     if sys.version_info < (3, 0):
         # Python 2
-        check_min_confidence(code, 50, {'a': dc, 'b': dc})
-        check_min_confidence(code, dc, {'a': dc, 'b': dc})
+        check_min_confidence(code, 50, {"a": dc, "b": dc})
+        check_min_confidence(code, dc, {"a": dc, "b": dc})
         check_min_confidence(code, 100, {})
     else:
         # Python 3
-        check_min_confidence(code, 50, {'a': 100, 'b': dc})
-        check_min_confidence(code, dc, {'a': 100, 'b': dc})
-        check_min_confidence(code, 100, {'a': 100})
+        check_min_confidence(code, 50, {"a": 100, "b": dc})
+        check_min_confidence(code, dc, {"a": 100, "b": dc})
+        check_min_confidence(code, 100, {"a": 100})
 
 
 def test_confidence_class():
@@ -59,13 +60,13 @@ def test_confidence_class():
 class Foo:
     pass
 """
-    check_min_confidence(code, 50, {'Foo': dc})
+    check_min_confidence(code, 50, {"Foo": dc})
     check_min_confidence(code, 100, {})
 
 
 def test_confidence_attr():
     code = "A.b = 'something'"
-    check_min_confidence(code, 50, {'b': dc})
+    check_min_confidence(code, 50, {"b": dc})
     check_min_confidence(code, 100, {})
 
 
@@ -78,7 +79,7 @@ class Foo:
 
 Foo()
 """
-    check_min_confidence(code, 50, {'some_prop': dc})
+    check_min_confidence(code, 50, {"some_prop": dc})
     check_min_confidence(code, 100, {})
 
 
@@ -91,5 +92,5 @@ async def foo():
     else:
         print("Else")
 """
-    check_min_confidence(code, 50, {'foo': dc})
+    check_min_confidence(code, 50, {"foo": dc})
     check_min_confidence(code, 75, {})
