@@ -1,8 +1,7 @@
-import sys
-
 import pytest
 
 from . import v
+
 assert v  # Silence pyflakes
 
 mock_code = """\
@@ -26,12 +25,13 @@ class Foo:
 
 @pytest.fixture
 def check_report(v, capsys):
-    def test_report(code, expected,  make_whitelist=False):
-        filename = 'foo.py'
+    def test_report(code, expected, make_whitelist=False):
+        filename = "foo.py"
         v.scan(code, filename=filename)
         capsys.readouterr()
         v.report(make_whitelist=make_whitelist)
         assert capsys.readouterr().out == expected.format(filename=filename)
+
     return test_report
 
 
@@ -45,8 +45,6 @@ def test_item_report(check_report):
 {filename}:11: unreachable code after 'return' (100% confidence)
 {filename}:13: unused property 'myprop' (60% confidence)
 """
-    if sys.version_info >= (3, 8):
-        expected = expected.replace("{filename}:13:", "{filename}:14:")
     check_report(mock_code, expected)
 
 
@@ -60,6 +58,4 @@ foobar  # unused variable ({filename}:9)
 # unreachable code after 'return' ({filename}:11)
 _.myprop  # unused property ({filename}:13)
 """
-    if sys.version_info >= (3, 8):
-        expected = expected.replace("{filename}:13)", "{filename}:14)")
     check_report(mock_code, expected, make_whitelist=True)
